@@ -24,7 +24,7 @@
 
 #include <QQuickItem>
 #include <QPointer>
-#include <QtCore/QVariant>
+#include <QVariant>
 #include <Plasma/Plasma>
 
 class QQuickItem;
