@@ -21,7 +21,6 @@
 #define APPLETQUICKITEM_H
 
 #include <QQuickItem>
-#include <QWeakPointer>
 #include <QQmlComponent>
 #include <QQmlEngine>
 #include <QTimer>
@@ -82,7 +81,7 @@ class PLASMAQUICK_EXPORT AppletQuickItem : public QQuickItem
 
     /**
      * True when the applet wants the activation signal act in toggle mode, i.e. while being expanded
-     * the signal shrinks the applet to its not exanded state instead of reexpanding it.
+     * the signal shrinks the applet to its not expanded state instead of reexpanding it.
      */
     Q_PROPERTY(bool activationTogglesExpanded WRITE setActivationTogglesExpanded READ isActivationTogglesExpanded NOTIFY activationTogglesExpandedChanged)
 
@@ -93,8 +92,8 @@ class PLASMAQUICK_EXPORT AppletQuickItem : public QQuickItem
     Q_PROPERTY(QObject *rootItem READ rootItem CONSTANT)
 
 public:
-    AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent = 0);
-    ~AppletQuickItem();
+    AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent = nullptr);
+    ~AppletQuickItem() override;
 
 ////API NOT SUPPOSED TO BE USED BY QML
     Plasma::Applet *applet() const;
@@ -102,11 +101,11 @@ public:
     //Make the constructor lighter and delay the actual instantiation of the qml in the applet
     virtual void init();
 
-    Plasma::Package appletPackage() const;
-    void setAppletPackage(const Plasma::Package &package);
+    PLASMA_DEPRECATED Plasma::Package appletPackage() const;
+    PLASMA_DEPRECATED void setAppletPackage(const Plasma::Package &package);
 
-    Plasma::Package coronaPackage() const;
-    void setCoronaPackage(const Plasma::Package &package);
+    PLASMA_DEPRECATED Plasma::Package coronaPackage() const;
+    PLASMA_DEPRECATED void setCoronaPackage(const Plasma::Package &package);
 
     QQuickItem *compactRepresentationItem();
     QQuickItem *fullRepresentationItem();
@@ -157,9 +156,9 @@ protected:
     KDeclarative::QmlObject *qmlObject();
 
     //Reimplementation
-    void childEvent(QChildEvent *event) Q_DECL_OVERRIDE;
-    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) Q_DECL_OVERRIDE;
-    void itemChange(ItemChange change, const ItemChangeData &value) Q_DECL_OVERRIDE;
+    void childEvent(QChildEvent *event) override;
+    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+    void itemChange(ItemChange change, const ItemChangeData &value) override;
 
 private:
     AppletQuickItemPrivate *const d;
